
XEP-0070: Verifying HTTP Requests via XMPP
==========================================

.. module:: slixmpp.plugins.xep_0070

.. autoclass:: XEP_0070
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0070.stanza
    :members:
    :undoc-members:

